==> freecad_0.16+dfsg2.orig.tar.xz: FreeCAD-0.16/src/Mod/Part/App/FeatureMirroring.h <==
/***************************************************************************
 *   Copyright (c) 2010 Werner Mayer <wmayer[at]users.sourceforge.net>     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef PART_FEATUREMIRRORING_H
#define PART_FEATUREMIRRORING_H

#include <App/PropertyStandard.h>
#include "PartFeature.h"
#include <Base/Matrix.h>

namespace Part
{

class Mirroring : public Part::Feature
{
    PROPERTY_HEADER(Part::Mirroring);

public:
    Mirroring();

    App::PropertyLink Source;
    App::PropertyVector Base;
    App::PropertyVector Normal;

    /** @name methods override feature */
    //@{
    /// recalculate the feature
    App::DocumentObjectExecReturn *execute(void);
    short mustExecute() const;
    /// returns the type name of the ViewProvider
    const char* getViewProviderName(void) const {
        return "PartGui::ViewProviderMirror";
    }
    //@}

protected:
    void onChanged (const App::Property* prop);
};

} //namespace Part


#endif // PART_FEATUREMIRRORING_H

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Part/App/FeatureMirroring.h <==
/***************************************************************************
 *   Copyright (c) 2010 Werner Mayer <wmayer[at]users.sourceforge.net>     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef PART_FEATUREMIRRORING_H
#define PART_FEATUREMIRRORING_H

#include <App/PropertyStandard.h>
#include "PartFeature.h"
#include <Base/Matrix.h>

namespace Part
{

class Mirroring : public Part::Feature
{
    PROPERTY_HEADER(Part::Mirroring);

public:
    Mirroring();

    App::PropertyLink Source;
    App::PropertyPosition Base;
    App::PropertyDirection Normal;

    /** @name methods override feature */
    //@{
    /// recalculate the feature
    App::DocumentObjectExecReturn *execute(void);
    short mustExecute() const;
    /// returns the type name of the ViewProvider
    const char* getViewProviderName(void) const {
        return "PartGui::ViewProviderMirror";
    }
    //@}

protected:
    void onChanged (const App::Property* prop);

    void handleChangedPropertyType(Base::XMLReader &reader, const char *TypeName, App::Property * prop);

};

} //namespace Part


#endif // PART_FEATUREMIRRORING_H
